@@ -1,5 +1,6 @@
 /* xpenguins_theme.c - provides the themability of xpenguins
  * Copyright (C) 1999-2001  Robin Hogan
+ * Copyright (C) 2002       Sebastian Henschel
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -323,6 +324,7 @@ xpenguins_free_list(char **list)
 
 /* Return the full path of the specified theme. Spaces in the theme
  * name are converted into underscores. */
+
 char *
 xpenguins_theme_directory(char *name)
 {
@@ -334,6 +336,7 @@ xpenguins_theme_directory(char *name)
   int string_length = 0, root_length;
   struct stat stat_buf;
 
+
   /* First look in $HOME/.xpenguins/themes for config */
   root_length = strlen(home) + strlen(home_root) + strlen(themes) + 1;
   string_length = root_length + strlen(name) + strlen(config) + 1;
@@ -342,6 +345,7 @@ xpenguins_theme_directory(char *name)
     xpenguins_out_of_memory();
     return NULL;
   }
+
   snprintf(config_path, string_length, "%s%s%s/%s%s",
 	   home, home_root, themes, name, config);
   /* Convert spaces to underscores */
@@ -352,6 +356,7 @@ xpenguins_theme_directory(char *name)
     }
     ++ch;
   }
+
   /* See if theme exists */
   if (stat(config_path, &stat_buf) == 0) {
     config_path[string_length-strlen(config)-1] = '\0';
@@ -380,6 +385,7 @@ xpenguins_theme_directory(char *name)
     }
     ++ch;
   }
+
   /* Look for theme */
   if (stat(config_path, &stat_buf) == 0) {
     config_path[string_length-strlen(config)-1] = '\0';
@@ -427,9 +433,7 @@ xpenguins_load_theme(char *name, XPenguinsTheme *theme)
   char started = 0;
 
   /* Find theme */
-  if (!file_name) {
-    return "Theme not found or config file not present";
-  }
+  if (!file_name) return "Theme not found or config file not present";
 
   /* Open config file */
   max_file_name_length = strlen(file_name) + 1 + MAX_STRING_LENGTH;
